export { isCancel } from "@clack/core";
export interface TextOptions {
	message: string;
	placeholder?: string;
	defaultValue?: string;
	initialValue?: string;
	validate?: (value: string) => string | void;
}
export declare function text(opts: TextOptions): Promise<string | symbol>;
export interface PasswordOptions {
	message: string;
	mask?: string;
	validate?: (value: string) => string | void;
}
export declare function password(opts: PasswordOptions): Promise<string | symbol>;
export interface ConfirmOptions {
	message: string;
	active?: string;
	inactive?: string;
	initialValue?: boolean;
}
export declare function confirm(opts: ConfirmOptions): Promise<boolean | symbol>;
type Primitive = Readonly<string | boolean | number>;
type Option<Value> = Value extends Primitive ? {
	value: Value;
	label?: string;
	hint?: string;
} : {
	value: Value;
	label: string;
	hint?: string;
};
export interface SelectOptions<Value> {
	message: string;
	options: Option<Value>[];
	initialValue?: Value;
	maxItems?: number;
}
export declare function select<Value>(opts: SelectOptions<Value>): Promise<Value | symbol>;
export declare function selectKey<Value extends string>(opts: SelectOptions<Value>): Promise<Value | symbol>;
export interface MultiSelectOptions<Value> {
	message: string;
	options: Option<Value>[];
	initialValues?: Value[];
	maxItems?: number;
	required?: boolean;
	cursorAt?: Value;
}
export declare function multiselect<Value>(opts: MultiSelectOptions<Value>): Promise<Value[] | symbol>;
export interface GroupMultiSelectOptions<Value> {
	message: string;
	options: Record<string, Option<Value>[]>;
	initialValues?: Value[];
	required?: boolean;
	cursorAt?: Value;
}
export declare function groupMultiselect<Value>(opts: GroupMultiSelectOptions<Value>): Promise<Value[] | symbol>;
export declare function note(message?: string, title?: string): void;
export declare function cancel(message?: string): void;
export declare function intro(title?: string): void;
export declare function outro(message?: string): void;
interface Spinner {
	start: (msg: string) => void;
	stop: (msg: string, code: number) => void;
	message: (msg: string) => void;
}
export declare function spinner(): Spinner;
export type PromptGroupAwaitedReturn<T> = { [P in keyof T] : Exclude<Awaited<T[P]>, symbol> };
export interface PromptGroupOptions<T> {
	/**
	* Control how the group can be canceled
	* if one of the prompts is canceled.
	*/
	onCancel?: (opts: { results: Prettify<Partial<PromptGroupAwaitedReturn<T>>> }) => void;
}
type Prettify<T> = { [P in keyof T] : T[P] } & {};
export type PromptGroup<T> = { [P in keyof T] : (opts: { results: Prettify<Partial<PromptGroupAwaitedReturn<Omit<T, P>>>> }) => void | Promise<T[P] | void> };
/**
* Define a group of prompts to be displayed
* and return a results of objects within the group
*/
export declare function group<T>(prompts: PromptGroup<T>, opts?: PromptGroupOptions<T>): Promise<Prettify<PromptGroupAwaitedReturn<T>>>;
export interface Task {
	/**
	* Task title
	*/
	title: string;
	/**
	* Task function
	*/
	task: (message: (string: string) => void) => string | Promise<string> | void | Promise<void>;
	/**
	* If enabled === false the task will be skipped
	*/
	enabled?: boolean;
}
/**
* Define a group of tasks to be executed
*/
export declare function tasks(tasks: Task[]): Promise<void>;
